==> pelican_4.7.1+dfsg.orig.tar.xz: pelican-4.7.1/.github/ISSUE_TEMPLATE/---bug-report.md <==
---
name: "\U0001F41E Bug Report"
about: Did you find a bug?
title: ''
labels: bug
assignees: ''

---

<!--
  Hi there! Thank you for discovering and submitting an issue.

  Before you submit this, let’s make sure of a few things.
  Please make sure the following boxes are ticked if they are correct.
  If not, please try and fulfill them first.
-->

<!-- Checked checkbox should look like this: [x] -->
- [ ] I have read the [Filing Issues](https://docs.getpelican.com/en/latest/contribute.html#filing-issues) and subsequent “How to Get Help” sections of the documentation.
- [ ] I have searched the [issues](https://github.com/getpelican/pelican/issues?q=is%3Aissue) (including closed ones) and believe that this is not a duplicate.

<!--
  Once the above boxes are checked, if you are able to fill in the following list
  with your information, it would be very helpful for maintainers.
-->

- **OS version and name**: <!-- Replace with version + name -->
- **Python version**: <!-- Replace with version -->
- **Pelican version**: <!-- Replace with version -->
- **Link to theme**: <!-- Replace with link to the theme you are using -->
- **Links to plugins**: <!-- Replace with list of links to plugins you are using -->
- **Link to your site**: <!-- If available, replace with link to your site -->
- **Link to your source**: <!-- If available, replace with link to relevant source repository -->
- **Link to a [Gist](https://gist.github.com/) with the contents of your settings file**: <!-- If your source is not accessible, put Gist link here -->

## Issue
<!--
  Now feel free to write your issue. Please avoid vague phrases like “[…] doesn’t work”.
  Be descriptive! Thanks again 🙌 ❤️
-->

==> pelican_4.11.0+dfsg.orig.tar.xz: pelican-4.11.0/.github/ISSUE_TEMPLATE/---bug-report.md <==
---
name: "\U0001F41E Bug Report"
about: Did you find a bug?
title: ''
labels: bug
assignees: ''

---

<!--
  Hi there! Thank you for discovering and submitting an issue.

  Before you submit this, let’s make sure of a few things.
  Please make sure the following boxes are ticked if they are correct.
  If not, please try and fulfill them first.
-->

<!-- Checked checkbox should look like this: [x] -->
- [ ] I have read the [Filing Issues](https://docs.getpelican.com/en/latest/contribute.html#filing-issues) and subsequent “How to Get Help” sections of the documentation.
- [ ] I can reproduce this problem with stock/default settings file, theme, and sample content (as described in above “How to Get Help” sections of the documentation).
- [ ] I have searched the [issues](https://github.com/getpelican/pelican/issues?q=is%3Aissue) (including closed ones) and believe that this is not a duplicate.

<!--
  If you cannot reproduce the problem with stock/default settings file, theme, and sample content,
  please close this tab and ask your question in the Discussions area instead:
  <https://github.com/getpelican/pelican/discussions>
  Otherwise, once the above boxes are checked, please fill out the following list
  of information, which would be very helpful for maintainers.
-->

- **OS version and name**: <!-- Replace with version + name -->
- **Python version**: <!-- Replace with version -->
- **Pelican version**: <!-- Replace with version -->
- **Link to theme**: <!-- Replace with link to the theme you are using -->
- **Links to plugins**: <!-- Replace with list of links to plugins you are using -->
- **Link to your site**: <!-- If available, replace with link to your site -->
- **Link to your source**: <!-- If available, replace with link to relevant source repository -->
- **Link to a [Gist](https://gist.github.com/) with the contents of your settings file**: <!-- If your source is not accessible, put Gist link here -->

## Issue
<!--
  Now feel free to write your issue. Please avoid vague phrases like “[…] doesn’t work”.
  Be descriptive! Thanks again 🙌 ❤️
-->
